#
# spec file for package dleyna-server
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2014 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dleyna-server
Version:        0.7.2
Release:        150400.1.6
Summary:        A DLNA media server
License:        LGPL-2.1-only
Group:          Productivity/Multimedia/Other
URL:            https://github.com/phako/dleyna-server
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dleyna-core-1.0) >= 0.6.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.36
BuildRequires:  pkgconfig(glib-2.0) >= 2.36
BuildRequires:  pkgconfig(gssdp-1.2) >= 0.13.2
BuildRequires:  pkgconfig(gupnp-1.2) >= 0.20.3
BuildRequires:  pkgconfig(gupnp-av-1.0) >= 0.12.9
BuildRequires:  pkgconfig(gupnp-dlna-2.0) >= 0.9.4
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.28.2
BuildRequires:  pkgconfig(libxml-2.0)
# As dleyna-server publishes itself on DBus, it needs access to the DBus connector
Requires:       dleyna-connector-dbus
Provides:       dbus(com.intel.dleyna-server) = %{version}

%description
dLeyna-server can be used in conjunction with a multimedia framework, such as GStreamer,
to implement a Digital Media Player. It can also be used to implement the
DLNA Download System Use Case.

%package devel
Summary:        Development files for the dleyna DLNA media server
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description devel
dLeyna-server can be used in conjunction with a multimedia framework, such as GStreamer,
to implement a Digital Media Player. It can also be used to implement the
DLNA Download System Use Case.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%files
%license COPYING
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/services/com.intel.dleyna-server.service
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/libdleyna-server-1.0.so.*
%{_libexecdir}/dleyna-server-service
%config %{_sysconfdir}/dleyna-server-service.conf

%files devel
%doc ChangeLog README.md
%{_includedir}/dleyna-1.0/
%{_libdir}/%{name}/libdleyna-server-1.0.so
%{_libdir}/pkgconfig/dleyna-server-service-1.0.pc

%changelog
* Sat Jan  8 2022 bjorn.lie@gmail.com
- Update to version 0.7.2:
  + Replace another SoupSessionAsync.
  + Fix unnecessary error logging on empty server responses.
* Sun Sep 26 2021 bjorn.lie@gmail.com
- Update to version 0.7.1:
  + Build fixes
  + Fix service file generation for non-default service name
  + Fix rpath linking errors
  + Do not use deprecated SoupSessionAsync
- Changes from version 0.7.0:
  + Port to GUPnP 1.2
  + Switch build system to meson
  + Drop signalfd for GLib's unix signal handling
  + Fix a potential crash when getting server properties
  + Add support for changing the D-Bus server name
  + Fix a use-after-free
  + Fix unintialized buffer use
- Add meson BuildRequires and macros + drop libtool BuildRequires:
  No longer needed following upstreams port.
- Add pkgconfig(libxml-2.0) BuildRequires: New dependency.
- Drop dleyna-server-port-gupnp1_2.patch: Fixed upstream.
- Update URL and Source to new home, as intel have dropped
  maintenance of this package, go with the leading fork.
* Sun Jul  7 2019 jengelh@inai.de
- Fixup RPM category groups.
- Use noun phrase in summaries. Avoid em dashes in summaries.
* Wed Jun 12 2019 bjorn.lie@gmail.com
- Add dleyna-server-port-gupnp1_2.patch: Port to gupnp-1.2.
  Following this: replace pkgconfig(gssdp-1.0) and
  pkgconfig(gupnp-1.0) with pkgconfig(gssdp-1.2) and
  pkgconfig(gupnp-1.2) BuildRequires.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb 16 2018 bjorn.lie@gmail.com
- Update to version 0.6.0:
  + [Props]: Fix ChildCount property type.
  + Added new core.c and core.h to Makefile.am.
  + Add Artist and AlbumArtURL to MediaContainer2.
  + ifaddrs.h for Andriod compile.
  + [m4]:
  - Don't use bash arrays in m4 macros.
  - Don't use bash "let" builtin.
  - Use AS_VAR_APPEND macro instead of "+=".
  + Fix possible use-after-free on exit.
  + Invalid log line.
  + Dereference of undefined pointer value.
  + Result of operation is garbage or undefined.
  + Include libgupnp/gupnp-context-manager.h.
- Drop dleyna-server-includes.patch: Fixed upstream.
- Do a minor spec cleanup.
- Add libtool BuildRequires and pass autoreconf, bootstrap tarball.
- Pass --disable-static to configure, ensure we do not build any
  static files.
* Mon Nov 14 2016 dimstar@opensuse.org
- Add dleyna-server-includes.patch: include the right headers to
  be able to compile against up-to-date gupnp stack
  (gh#01org/dleyna-server#159).
* Sat May  2 2015 zaitor@opensuse.org
- Update to version 0.5.0:
  + [Build] Fix out-of-source-tree builds.
  + Fix various configure & build issues.
  + [Autoconf]:
  - Sub Makefile: Remove ACLOCAL_AMFLAGS.
  - Add --no-undefined to compiler option.
  + [upnp] Use "port" setting when creating GUPnPContextManager.
  + [Deprecated API] Use new API instead of deprecated.
  + [Device]:
  - Fix wake-on ip address used for broadcast.
  - Sleeping devices cache cleanup.
  - Improve sleeping context lookup.
  - Move the network interface info storage.
  - Improve Network Interface info and device context matching.
  - RetrieFve sleeping state via GetInterfaceInfo action.
  - Add sleeping device memory cache.
  - Add wake packet sending support.
  - Add Energy Management features.
  + [Configuration] Remove libdleyna-server .pc file.
  + [Documentation] Fix URL to MediaServer2Spec.
  + [Tests]:
  - Save changed ServiceResetToken in configuration.
  - Survive a missing ServiceResetToken in dsc.
  - Fix a typo in the Upload Sync Controller's error management.
* Fri Oct 17 2014 dimstar@opensuse.org
- Require dleyna-connector-dbus: dleyna-server includes a
  dbus-service and relies thus on dleyna-connector-dbus (at this
  moment this is the only supported connector).
* Tue Sep 16 2014 dimstar@opensuse.org
- Package COPYING file.
* Thu Sep 11 2014 dimstar@opensuse.org
- Initial package, version 0.4.0.
